#!/usr/bin/perl -w

# MQseries Queues monitor Nagios-plugin
# Author: Ivan Fontan (chernobil@gmail.com)
#
# SYNTAX
# check_mqseries [hostname] [queuechannel] [port] [quemanager] [queuename] [warnnum] [critnum]
#
# Example:
# command[check_queue1]=/some/path/libexec/check_mqseries hostname1 CHANNEL1.CHN 1414 QM1.QM QUEUE1.Q 2000 5000
#
# current status: $Revision: 1.0 $
#
# Copyright Notice: GPL
# $Id: check_mqseries,v 1.0 2004/09/15 04:27:32 ifontan Exp $

use MQClient::MQSeries;
use MQSeries::Command;

my $hostname=$ARGV[0];
my $queuechannel=$ARGV[1];
my $port=$ARGV[2];
my $queuemanager=$ARGV[3];
my $queuename=$ARGV[4];
my $warnnum=$ARGV[5];
my $critnum=$ARGV[6];

if ($#ARGV < 6) {
die "\n",
    "Copyright (c) 2004 Ivan Fontan\n",
    "\n",
    "Check deepness of MQSeries Queues.\n",
    "\n",
    "Usage: check_mqseries [hostname] [queuechannel] [port] [quemanager] [queuename] [warnnum] [critnum]\n",
    "\n",
    "[hostname] - Name or IP of MQSeries server\n",
    "[queuechannel] - Name of queue channel containing queue we want to monitor\n",
    "[port] - Port of queue channel containing queue we want to monitor (Usually 1414)\n",
    "[queuemanager] - Name of queue manager containing queue we want to monitor\n",
    "[queuename] - Name of queue we want to monitor\n",
    "[warnnum] - Number of max messages in the queue before a WARNING is send to Nagios\n",
    "[critnum] - Number of max messages in the queue before a CRITICAL is send to Nagios\n",
    "\n",
    "Command example:\n",
    "command[check_queue1]=/some/path/libexec/check_mqs hostname1 CHANNEL1.CHN 1414 QM1.QM QUEUE1.Q 2000 5000\n",
    "\n";
}

$ENV{MQSERVER}="$queuechannel/TCP/$hostname($port)";
my $CurrentQDepth=0;
my @queue=$queuename;
my $command = MQSeries::Command->new;

for my $qname ( @queue ){

        $attr = $command->InquireQueue
        (
                QName           => $qname,
                QAttrs          => [qw(
                                        CurrentQDepth
                                )],
        ) or die "InquireQueue: " . MQReasonToText($command->Reason()) . "\n";

        for my $key ( sort keys %$attr ) {
               if($key eq "CurrentQDepth") {
                        $CurrentQDepth = $attr->{$key};
               if ($attr->{$key} > $critnum) {
                        print "CRITICAL - Queue problem: $qname is oversized. Actual deep: $attr->{$key}\n";
                        exit 1;
                }
                if ($attr->{$key} > $warnnum) {
                        print "WARNING - Queue problem: $qname is near out of bounds. Actual deep: $attr->{$key}\n";
                        exit 2;
                }
                        print "OK - Queue $qname is in correct bounds. Actual deep: $attr->{$key}\n";
                        exit 0;
                }
        }
}